@@ -1679,7 +1679,9 @@ class ApigatewayClient(AbstractClient):
 
 
     def GenerateApiDocument(self, request):
-        """本接口（GenerateApiDocument）用于自动生成 API 文档和 SDK，一个服务的一个环境生成一份文档和 SDK。
+        """接口已废弃
+
+        本接口（GenerateApiDocument）用于自动生成 API 文档和 SDK，一个服务的一个环境生成一份文档和 SDK。
 
         :param request: Request instance for GenerateApiDocument.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.GenerateApiDocumentRequest`
